==> vue-cli-plugin-logwire-backend-0.1.0.tgz: package/ui.js <==
const fs = require('fs')

function installStorageData (api) {
  let confPath = api.resolve('.logwire')
  if (fs.existsSync(confPath)) {
    let conf = fs.readFileSync(confPath, { encoding: 'utf8' })
    conf = JSON.parse(conf)
    api.setSharedData('com.logwire.configuration.backend', conf.backend)
    api.setSharedData('com.logwire.configuration.gateway', conf.gateway)
  } else {
    fs.writeFileSync(confPath, JSON.stringify({ backend: '', gateway: '' }, null, '\t'))
  }

  api.onAction('com.logwire.actions.saveConfiguration', params => {
    let { data } = params
    fs.writeFileSync(confPath, JSON.stringify(data, null, '\t'))
    api.setSharedData('com.logwire.configuration.backend', data.backend)
    api.setSharedData('com.logwire.configuration.gateway', data.gateway)
  })
}

function installInjectGitignore (api) {
  let gitPath = api.resolve('.gitignore')
  console.log(gitPath)
  if (fs.existsSync(gitPath)) {
    let conf = fs.readFileSync(gitPath, { encoding: 'utf8' })
    if (!/\n\.logwire/.test(conf)) {
      conf += '\n#vue-cli插件配置\n.logwire'
      fs.writeFileSync(gitPath, conf)
    }
  } else {
    let conf = '#vue-cli插件配置\n.logwire'
    fs.writeFileSync(gitPath, conf)
  }
}

// const root = 'localhost'
module.exports = (api) => {
  api.addClientAddon({
    id: 'com.logwire.client-addon',
    url: 'vue-cli-plugin-logwire-backend/dist'
  })
  api.addView({
    id: 'com.logwire.views.test',
    name: 'com.logwire.routes.test',
    icon: 'pets',
    tooltip: 'Logwire'
  })

  // 获取项目根目录下的配置文件信息，放入共享数据中
  installStorageData(api)
  installInjectGitignore(api)
}

==> vue-cli-plugin-logwire-backend-0.2.0.tgz: package/ui.js <==
const fs = require('fs')

function installStorageData (api) {
  let confPath = api.resolve('.logwire')
  if (fs.existsSync(confPath)) {
    let conf = fs.readFileSync(confPath, { encoding: 'utf8' })
    conf = JSON.parse(conf)
    api.setSharedData('com.logwire.configuration.backend', conf.backend)
    api.setSharedData('com.logwire.configuration.gateway', conf.gateway)
  } else {
    fs.writeFileSync(confPath, JSON.stringify({ backend: '', gateway: '' }, null, '\t'))
  }

  api.onAction('com.logwire.actions.saveConfiguration', params => {
    let { data } = params
    fs.writeFileSync(confPath, JSON.stringify(data, null, '\t'))
    api.setSharedData('com.logwire.configuration.backend', data.backend)
    api.setSharedData('com.logwire.configuration.gateway', data.gateway)
  })
}

function installInjectGitignore (api) {
  let gitPath = api.resolve('.gitignore')
  console.log(gitPath)
  if (fs.existsSync(gitPath)) {
    let conf = fs.readFileSync(gitPath, { encoding: 'utf8' })
    if (!/\n\.logwire/.test(conf)) {
      conf += '\n#vue-cli插件配置\n.logwire'
      fs.writeFileSync(gitPath, conf)
    }
  } else {
    let conf = '#vue-cli插件配置\n.logwire'
    fs.writeFileSync(gitPath, conf)
  }
}

// const root = 'localhost'
module.exports = (api) => {
  api.addClientAddon({
    id: 'com.logwire.client-addon',
    path: 'vue-cli-plugin-logwire-backend/dist'
  })
  api.addView({
    id: 'com.logwire.views.test',
    name: 'com.logwire.routes.test',
    icon: 'pets',
    tooltip: 'Logwire'
  })

  // 获取项目根目录下的配置文件信息，放入共享数据中
  installStorageData(api)
  installInjectGitignore(api)
}
